pub struct TreeShakeOptions {
pub annotations: Option<bool>,
pub manual_pure_functions: Option<Vec<String>>,
pub property_read_side_effects: Option<Either<bool, String>>,
pub property_write_side_effects: Option<bool>,
pub unknown_global_side_effects: Option<bool>,
pub invalid_import_side_effects: Option<bool>,
}Fields
annotations: Option<bool>Whether to respect the pure annotations.
Pure annotations are comments that mark an expression as pure. For example: @PURE or #NO_SIDE_EFFECTS.
@default true
manual_pure_functions: Option<Vec<String>>Whether to treat this function call as pure.
This function is called for normal function calls, new calls, and tagged template calls.
property_read_side_effects: Option<Either<bool, String>>Whether property read accesses have side effects.
@default ‘always’
property_write_side_effects: Option<bool>Whether property write accesses (assignments to member expressions) have side effects.
When false, assignments like obj.prop = value are considered side-effect-free
(assuming the object and value expressions themselves are side-effect-free).
@default true
unknown_global_side_effects: Option<bool>Whether accessing a global variable has side effects.
Accessing a non-existing global variable will throw an error. Global variable may be a getter that has side effects.
@default true
invalid_import_side_effects: Option<bool>Whether invalid import statements have side effects.
Accessing a non-existing import name will throw an error. Also import statements that cannot be resolved will throw an error.
@default true